@@ -35,15 +35,19 @@
 #include "gsocks4proxy.h"
 #include "gsocks4aproxy.h"
 #include "gsocks5proxy.h"
+#include "gtlsbackend.h"
 #include "gvfs.h"
-#ifdef G_OS_UNIX
-#include "gdesktopappinfo.h"
-#endif
 #ifdef G_OS_WIN32
 #include "gregistrysettingsbackend.h"
 #endif
 #include <glib/gstdio.h>
 
+#undef G_DISABLE_DEPRECATED
+
+#ifdef G_OS_UNIX
+#include "gdesktopappinfo.h"
+#endif
+
 /**
  * SECTION:giomodule
  * @short_description: Loadable GIO Modules
@@ -274,7 +278,7 @@ is_valid_module_name (const gchar *basename)
  * g_io_extension_point_get_extension_by_name().
  *
  * If you need to guarantee that all types are loaded in all the modules,
- * use g_io_modules_scan_all_in_directory().
+ * use g_io_modules_load_all_in_directory().
  *
  * Since: 2.24
  **/
@@ -477,6 +481,7 @@ extern GType g_win32_directory_monitor_get_type (void);
 extern GType _g_winhttp_vfs_get_type (void);
 
 extern GType _g_dummy_proxy_resolver_get_type (void);
+extern GType _g_dummy_tls_backend_get_type (void);
 
 #ifdef G_PLATFORM_WIN32
 
@@ -523,6 +528,13 @@ _g_io_modules_ensure_extension_points_registered (void)
     {
       registered_extensions = TRUE;
       
+#ifdef G_OS_UNIX
+#if !GLIB_CHECK_VERSION (3, 0, 0)
+      ep = g_io_extension_point_register (G_DESKTOP_APP_INFO_LOOKUP_EXTENSION_POINT_NAME);
+      g_io_extension_point_set_required_type (ep, G_TYPE_DESKTOP_APP_INFO_LOOKUP);
+#endif
+#endif
+      
       ep = g_io_extension_point_register (G_LOCAL_DIRECTORY_MONITOR_EXTENSION_POINT_NAME);
       g_io_extension_point_set_required_type (ep, G_TYPE_LOCAL_DIRECTORY_MONITOR);
       
@@ -546,6 +558,9 @@ _g_io_modules_ensure_extension_points_registered (void)
 
       ep = g_io_extension_point_register (G_PROXY_EXTENSION_POINT_NAME);
       g_io_extension_point_set_required_type (ep, G_TYPE_PROXY);
+
+      ep = g_io_extension_point_register (G_TLS_BACKEND_EXTENSION_POINT_NAME);
+      g_io_extension_point_set_required_type (ep, G_TYPE_TLS_BACKEND);
     }
   
   G_UNLOCK (registered_extensions);
@@ -608,6 +623,7 @@ _g_io_modules_ensure_loaded (void)
       _g_socks4a_proxy_get_type ();
       _g_socks4_proxy_get_type ();
       _g_socks5_proxy_get_type ();
+      _g_dummy_tls_backend_get_type ();
     }
 
   G_UNLOCK (loaded_dirs);
