@@ -187,7 +187,7 @@
  *       return;
  *     }
  *
- *   _baker_prepare_cake (self, radius, baked_cb, user_data);
+ *   _baker_prepare_cake (self, radius, baked_cb, simple);
  * }
  *
  * Cake *
@@ -299,8 +299,7 @@ g_simple_async_result_init (GSimpleAsyncResult *simple)
 
 /**
  * g_simple_async_result_new:
- * @source_object: a #GObject the asynchronous function was called with,
- * or %NULL.
+ * @source_object: (allow-none): a #GObject, or %NULL.
  * @callback: a #GAsyncReadyCallback.
  * @user_data: user data passed to @callback.
  * @source_tag: the asynchronous function.
@@ -333,7 +332,7 @@ g_simple_async_result_new (GObject             *source_object,
 
 /**
  * g_simple_async_result_new_from_error:
- * @source_object: a #GObject, or %NULL.
+ * @source_object: (allow-none): a #GObject, or %NULL.
  * @callback: a #GAsyncReadyCallback.
  * @user_data: user data passed to @callback.
  * @error: a #GError
@@ -394,7 +393,7 @@ g_simple_async_result_new_take_error (GObject             *source_object,
 
 /**
  * g_simple_async_result_new_error:
- * @source_object: a #GObject, or %NULL.
+ * @source_object: (allow-none): a #GObject, or %NULL.
  * @callback: a #GAsyncReadyCallback.
  * @user_data: user data passed to @callback.
  * @domain: a #GQuark.
@@ -533,7 +532,7 @@ g_simple_async_result_set_op_res_gpointer (GSimpleAsyncResult *simple,
 }
 
 /**
- * g_simple_async_result_get_op_res_gpointer: (skip):
+ * g_simple_async_result_get_op_res_gpointer: (skip)
  * @simple: a #GSimpleAsyncResult.
  *
  * Gets a pointer result as returned by the asynchronous function.
@@ -904,6 +903,8 @@ g_simple_async_result_run_in_thread (GSimpleAsyncResult     *simple,
  * _finish function from which this function is called).
  *
  * Returns: #TRUE if all checks passed or #FALSE if any failed.
+ *
+ * Since: 2.20
  **/
 gboolean
 g_simple_async_result_is_valid (GAsyncResult *result,
@@ -933,7 +934,7 @@ g_simple_async_result_is_valid (GAsyncResult *result,
 
 /**
  * g_simple_async_report_error_in_idle:
- * @object: a #GObject.
+ * @object: (allow-none): a #GObject, or %NULL.
  * @callback: a #GAsyncReadyCallback.
  * @user_data: user data passed to @callback.
  * @domain: a #GQuark containing the error domain (usually #G_IO_ERROR).
@@ -957,7 +958,7 @@ g_simple_async_report_error_in_idle (GObject             *object,
   GSimpleAsyncResult *simple;
   va_list args;
  
-  g_return_if_fail (G_IS_OBJECT (object));
+  g_return_if_fail (!object || G_IS_OBJECT (object));
   g_return_if_fail (domain != 0);
   g_return_if_fail (format != NULL);
 
@@ -974,7 +975,7 @@ g_simple_async_report_error_in_idle (GObject             *object,
 
 /**
  * g_simple_async_report_gerror_in_idle:
- * @object: a #GObject.
+ * @object: (allow-none): a #GObject, or %NULL
  * @callback: a #GAsyncReadyCallback.
  * @user_data: user data passed to @callback.
  * @error: the #GError to report
@@ -991,7 +992,7 @@ g_simple_async_report_gerror_in_idle (GObject *object,
 {
   GSimpleAsyncResult *simple;
  
-  g_return_if_fail (G_IS_OBJECT (object));
+  g_return_if_fail (!object || G_IS_OBJECT (object));
   g_return_if_fail (error != NULL);
 
   simple = g_simple_async_result_new_from_error (object,
@@ -1004,7 +1005,7 @@ g_simple_async_report_gerror_in_idle (GObject *object,
 
 /**
  * g_simple_async_report_take_gerror_in_idle:
- * @object: a #GObject.
+ * @object: (allow-none): a #GObject, or %NULL
  * @callback: a #GAsyncReadyCallback.
  * @user_data: user data passed to @callback.
  * @error: the #GError to report
@@ -1023,7 +1024,7 @@ g_simple_async_report_take_gerror_in_idle (GObject *object,
 {
   GSimpleAsyncResult *simple;
 
-  g_return_if_fail (G_IS_OBJECT (object));
+  g_return_if_fail (!object || G_IS_OBJECT (object));
   g_return_if_fail (error != NULL);
 
   simple = g_simple_async_result_new_take_error (object,
